@@ -6,7 +6,7 @@ use std::convert::TryFrom;
 const METERS_PER_MILE: f64 = 1609.344;
 
 /// Distance in meters
-#[derive(Into, Debug, PartialEq, Copy, Clone, PartialOrd, Serialize, Deserialize)]
+#[derive(Into, Debug, PartialEq, Copy, Clone, PartialOrd, Serialize, Deserialize, Default)]
 #[serde(into = "f64", try_from = "f64")]
 pub struct Distance(f64);
 
